import { callApiWithAuth, getExtensionId, ensureValidToken } from '/scripts/utils/auth.js';
import { API_BASE } from '/scripts/config.js';

// Add this constant at the top of the file
const WHITELISTED_SITES = [
  // AI & Search
  'chatgpt.com',
  'chat.openai.com',
  'perplexity.ai',
  'bard.google.com',
  'claude.ai',
  'anthropic.com',
  'cohere.ai',
  'huggingface.co',
  'poe.com',
  'copilot.microsoft.com',
  
  // Email Services
  'mail.google.com',  // Gmail
  'outlook.com',      // Outlook
  'outlook.office.com',
  'outlook.live.com',
  'yahoo.mail.com',   // Yahoo Mail
  'proton.me',        // ProtonMail
  'zoho.com/mail',    // Zoho
  'fastmail.com',     // FastMail
  'tutanota.com'      // Tutanota
];

// Add these constants at the top with the existing WHITELISTED_SITES
const BIG_SITES = ['google.com', 'reddit.com', 'duckduckgo.com'];
const MAX_FEEDBACK_ENTRIES = 200;

// Add to top with other constants
const PHONE_CHECK_INTERVAL = 60000; // Change to 60 seconds
const MAX_PHONE_CHECK_ATTEMPTS = 5;

// At the top with other constants
const PHONE_CHECK_ALARM = 'phoneCheckAlarm';

let relaxMode = false;
let relaxEndTime = null;

// Add new state variables
let phoneCheckTimer = null;
let phoneCheckAttempts = 0;

// Initialize storage with default values if not set
chrome.runtime.onInstalled.addListener(async () => {
  await getExtensionId();
  await ensureValidToken(); // This will get a new anonymous token
  chrome.storage.local.get(['sprintGoal'], function(data) {
    if (!data.sprintGoal) {
      chrome.storage.local.set({
        sprintGoal: ''
      });
    }
  });
});

chrome.runtime.onStartup.addListener(async () => {
  await getExtensionId();
  await ensureValidToken();
});

// Listen for tab updates to track URL changes
chrome.tabs.onUpdated.addListener(async function(tabId, changeInfo, tab) {
  if (changeInfo.status === 'complete' && tab.url) {
    processActivity(tab.url, tabId);
  }
});

// Listen for relax mode toggle messages from popup
chrome.runtime.onMessage.addListener((msg, sender, sendResponse) => {
  if (msg.type === "RELAX_MODE_ON") {
    chrome.storage.local.set({
      relaxMode: true,
      relaxEndTime: msg.until // null for indefinite, timestamp for timed
    });
    return true;
  }
  if (msg.type === "RELAX_MODE_OFF") {
    relaxMode = false;
    relaxEndTime = null;
    chrome.alarms.clear("endRelaxMode");
    chrome.storage.local.set({ relaxMode: false, relaxEndTime: null });
  }

  // --- Phone check integration ---
  if (msg.type === "FOCUS_MODE_ON") {
    // 1. Generate a new session ID
    const focusSessionId = crypto.randomUUID();

    // 2. Store it in chrome.storage.local, then start phone check
    chrome.storage.local.set({
      focusSessionId,
      phoneCheckStatus: {
        isPhoneOff: false,
        checkAttempts: 0,
        lastCheckTime: null
      }
    }).then(() => {
      startPhoneCheck();
      sendResponse({ success: true });
    });
    return true; // Indicate async response
  }
  if (msg.type === "FOCUS_MODE_OFF") {
    stopPhoneCheck();
    chrome.storage.local.set({ 
      focusSessionId: null,
      phoneCheckStatus: {
        isPhoneOff: false,
        checkAttempts: 0,
        lastCheckTime: null
      }
    }).then(() => {
      sendResponse({ success: true });
    });
    return true; // Indicate async response
  }
});

// Listen for alarm to end relax mode
chrome.alarms.onAlarm.addListener((alarm) => {
  if (alarm.name === "endRelaxMode") {
    relaxMode = false;
    relaxEndTime = null;
    chrome.storage.local.set({ relaxMode: false, relaxEndTime: null });
    chrome.runtime.sendMessage({ type: "RELAX_MODE_ENDED" });
  }
});

// Register alarm listener (add this near the top with other listeners)
chrome.alarms.onAlarm.addListener((alarm) => {
  if (alarm.name === PHONE_CHECK_ALARM) {
    console.log('Phone check alarm triggered');
    doPhoneCheck();
  }
});

// Add these helper functions at the top of background.js
function normalizeDomain(domain) {
  return domain.toLowerCase().replace(/^www\./, '');
}

function isSpecialSite(url) {
  const domain = new URL(url).hostname;
  return BIG_SITES.some(site => domain.includes(site));
}

function extractSearchPattern(url) {
  const urlObj = new URL(url);
  const domain = urlObj.hostname;
  if (domain.includes('reddit.com')) {
    // Reddit search: /search?q=...
    if (urlObj.pathname.startsWith('/search')) {
      return urlObj.searchParams.get('q') || '';
    }
    // Subreddit: /r/...
    if (urlObj.pathname.startsWith('/r/')) {
      return urlObj.pathname.split('/')[2] || '';
    }
  }
  if (domain.includes('google.com') || domain.includes('duckduckgo.com')) {
    return urlObj.searchParams.get('q') || '';
  }
  return '';
}
// Helper: Get domain from URL
function getDomain(url) {
  try {
    return new URL(url).hostname.replace(/^www\./, '');
  } catch {
    return '';
  }
}

// Helper to get the active goal and its whitelist
async function getActiveGoalAndWhitelist() {
  return new Promise((resolve) => {
    chrome.storage.local.get(['goals', 'activeGoalId'], (data) => {
      const goals = data.goals || {};
      const activeGoalId = data.activeGoalId;
      const activeGoal = goals[activeGoalId] || null;
      const whitelist = (activeGoal && activeGoal.whitelistedSites) ? Object.keys(activeGoal.whitelistedSites) : [];
      resolve({ activeGoal, whitelist });
    });
  });
}

// Add this helper function at the top with other helpers
function extractBaseDomain(url) {
  try {
    const hostname = new URL(url).hostname.replace(/^www\./, '');
    const parts = hostname.split('.');
    if (parts.length > 2) {
      return parts.slice(-2).join('.');
    }
    return hostname;
  } catch (e) {
    console.error('Invalid URL:', url);
    return null;
  }
}

// Process the current activity
async function processActivity(url, tabId) {
  // Skip chrome:// URLs first
  if (url.startsWith('chrome://')) return;

  // Get both focus and relax mode status
  const { focusMode, relaxMode, relaxEndTime } = await chrome.storage.local.get(['focusMode', 'relaxMode', 'relaxEndTime']);
  
  // If focus mode is off OR relax mode is on, skip all processing
  if (!focusMode || (relaxMode && (relaxEndTime === null || Date.now() < relaxEndTime))) {
    return;
  }

  // Use extractBaseDomain for ALL domain checks
  const baseDomain = extractBaseDomain(url);

  // Check global whitelist first, before any other processing
  if (WHITELISTED_SITES.includes(baseDomain)) {
    console.log('Globally whitelisted site, allowing:', baseDomain);
    return;
  }

  // Check if it's a homepage of a big site (add this check early)
  if (isBigSiteHomepage(url)) {
    console.log('Big site homepage, allowing:', url);
    return;
  }

  const urlObj = new URL(url);
  
  // Get active goal and its whitelist/patterns
  const { goals, activeGoalId, feedbackByGoal = {} } = await chrome.storage.local.get(['goals', 'activeGoalId', 'feedbackByGoal']);
  const activeGoal = goals?.[activeGoalId];
  
  if (!activeGoal) {
    return;
  }

  // Check whitelist before making API call
  if (baseDomain && !BIG_SITES.includes(baseDomain)) {
    const goalWhitelist = Object.keys(activeGoal.whitelistedSites || {});
    if (goalWhitelist.includes(baseDomain)) {
      console.log(`URL allowed through whitelist: ${baseDomain}`);
      return;
    }
  }

  // If not whitelisted, proceed with classification
  try {
    // Format feedback list for backend
    const feedbackList = (activeGoal.feedbackList || []).map(f => ({
      pattern: f.pattern,
      explanation: f.explanation
    }));

    console.log("Sending to classify:", { 
      url,
      sprintGoal: activeGoal.text,
      feedbackList
    });

    const result = await callApiWithAuth(`${API_BASE}/api/classify`, {
      url,
      sprintGoal: activeGoal.text,
      feedbackList
    });

    console.log("Classification result:", result);
    
    if (result.aligned) {
      if (baseDomain && !BIG_SITES.includes(baseDomain)) {
        // Auto-whitelist the domain for this goal
        activeGoal.whitelistedSites = activeGoal.whitelistedSites || {};
        activeGoal.whitelistedSites[baseDomain] = true;
        await chrome.storage.local.set({ goals });
        console.log(`Auto-whitelisted ${baseDomain} for goal: ${activeGoal.text}`);
      }
    } else {
      chrome.tabs.get(tabId, function(tab) {
        if (tab) {
          injectWarningIfNeeded(tab);
        }
      });
    }
  } catch (error) {
    console.error('Error classifying URL:', error);
  }
}

// Store feedback per sprint goal
async function storeFeedback(url, feedback, activeGoal) {
  const domain = normalizeDomain(new URL(url).hostname);
  
  // Get current feedback data
  const { feedbackByGoal = {} } = await chrome.storage.local.get(['feedbackByGoal']);
  const goalKey = activeGoal.text || '';
  let goalData = feedbackByGoal[goalKey] || { whitelistedDomains: [], patterns: [] };

  if (isSpecialSite(url)) {
    // For special sites, store the search pattern
    const pattern = extractSearchPattern(url);
    if (pattern && !goalData.patterns.some(p => p.pattern === pattern)) {
      goalData.patterns.push({ 
        pattern,
        explanation: feedback,
        timestamp: Date.now()
      });
    }
  } else {
    // For regular sites, whitelist the domain
    if (!goalData.whitelistedDomains.includes(domain)) {
      goalData.whitelistedDomains.push(domain);
    }
  }

  // Update storage
  feedbackByGoal[goalKey] = goalData;
  await chrome.storage.local.set({ feedbackByGoal });
  
  // Also update the goal's whitelist
  const { goals } = await chrome.storage.local.get(['goals']);
  if (goals[activeGoal.id]) {
    goals[activeGoal.id].whitelistedSites = goals[activeGoal.id].whitelistedSites || {};
    goals[activeGoal.id].whitelistedSites[domain] = true;
    await chrome.storage.local.set({ goals });
  }
}

// Helper function to update goal feedback
async function updateGoalFeedback(activity, userReason) {
  return new Promise((resolve) => {
    chrome.storage.local.get(['goals', 'activeGoalId'], (data) => {
      const goals = data.goals || {};
      const activeGoalId = data.activeGoalId;
      const activeGoal = goals[activeGoalId];

      if (!activeGoal) return resolve(false);

      // Clean the pattern for big sites, otherwise use the domain or url
      let pattern = activity;
      if (isSpecialSite(activity)) {
        pattern = extractSearchPattern(activity) || activity;
      }

      // Store feedback in format matching backend
      activeGoal.feedbackList = activeGoal.feedbackList || [];
      activeGoal.feedbackList.push({
        pattern,
        explanation: userReason,
        timestamp: Date.now()
      });

      // Keep only latest MAX_FEEDBACK_ENTRIES
      if (activeGoal.feedbackList.length > MAX_FEEDBACK_ENTRIES) {
        activeGoal.feedbackList = activeGoal.feedbackList
          .sort((a, b) => b.timestamp - a.timestamp)
          .slice(0, MAX_FEEDBACK_ENTRIES);
      }

      // Add to whitelist if not a big site
      const baseDomain = extractBaseDomain(activity);
      if (baseDomain && !BIG_SITES.includes(baseDomain)) {
        activeGoal.whitelistedSites = activeGoal.whitelistedSites || {};
        activeGoal.whitelistedSites[baseDomain] = true;
      }

      goals[activeGoalId] = activeGoal;
      chrome.storage.local.set({ goals }, () => resolve(true));
    });
  });
}

// Update the message listener to handle feedback submission
chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
  if (message.type === 'SUBMIT_FEEDBACK') {
    // First update local storage
    updateGoalFeedback(message.url, message.feedback)
      .then(async () => {
        // Get the active goal
        const { activeGoal } = await getActiveGoalAndWhitelist();
        
        // Then track the feedback event via API
        try {
          const response = await callApiWithAuth(`${API_BASE}/api/feedback`, {
            url: message.url,
            feedback: {
              aligned: false,
              explanation: message.feedback
            },
            sprintGoal: activeGoal?.text || '',
            activityContent: message.url
          });
          sendResponse(true);
        } catch (err) {
          console.error('Error submitting feedback:', err);
          sendResponse(false);
        }
      })
      .catch(err => {
        console.error('Error storing feedback:', err);
        sendResponse(false);
      });
    return true; // Keep the message channel open for async response
  }
  // ... keep other existing message handlers ...
});

// Show warning popup
async function injectWarningIfNeeded(tab) {
  if (shouldBlockForRelax()) {
    return;
  }
  
  // Get the active goal first
  const { activeGoal } = await getActiveGoalAndWhitelist();
  const sprintGoal = activeGoal ? activeGoal.text : '';
  
  chrome.scripting.executeScript({
    target: { tabId: tab.id },
    function: createWarningPopup,
    args: [
      chrome.runtime.getURL('assets/disappointed_meme.jpg'),
      sprintGoal
    ]
  });
}

// Function to be injected into the page
function createWarningPopup(memeURL, sprintGoal) {
  if (document.getElementById('deepwork-defender-warning-overlay')) {
    return;
  }

  // Create overlay container
  const overlay = document.createElement('div');
  overlay.id = 'deepwork-defender-warning-overlay';

  // Attach shadow root
  const shadow = overlay.attachShadow({ mode: 'open' });

  // Get the correct path for the SVG asset
  const guardImgSrc = chrome.runtime.getURL('assets/soldier_head_transparent.png');

  shadow.innerHTML = `
    <style>
      :host {
        position: fixed;
        top: 0; left: 0; right: 0; bottom: 0;
        z-index: 999999;
        display: flex;
        align-items: center;
        justify-content: center;
      }
      .frosted-bg {
        position: fixed;
        top: 0; left: 0; right: 0; bottom: 0;
        background: rgba(30, 41, 59, 0.35);
        backdrop-filter: blur(10px) brightness(0.95);
        z-index: 1;
        overflow: hidden;
      }
      .checkpoint-barrier {
        position: absolute;
        left: 50%;
        top: 60%;
        transform: translate(-50%, -50%);
        width: 420px;
        max-width: 90vw;
        opacity: 0.18;
        z-index: 2;
        pointer-events: none;
      }
      .popup {
        position: relative;
        z-index: 3;
        background: #232b22;
        border-radius: 22px;
        box-shadow: 0 8px 40px rgba(0,0,0,0.22), 0 1.5px 6px rgba(0,0,0,0.10);
        width: 370px;
        max-width: 92vw;
        padding: 0;
        font-family: 'Inter', 'Segoe UI', Arial, sans-serif;
        overflow: hidden;
        display: flex;
        flex-direction: column;
        align-items: stretch;
        border: 4px solid #bfcf9b;
        box-sizing: border-box;
      }
      .popup-header {
        background: linear-gradient(90deg, #bfcf9b 0%, #6b7a4b 100%);
        color: #fff;
        border-radius: 18px 18px 0 0;
        padding: 22px 0 18px 32px;
        font-size: 2em;
        font-weight: 700;
        display: flex;
        align-items: center;
        gap: 18px;
        margin-bottom: 28px;
        border-bottom: 3px solid #e2e8ce;
        letter-spacing: 1px;
      }
      .guard-svg {
        width: 80px;
        height: 80px;
        margin-right: 10px;
        flex-shrink: 0;
      }
      .checkpoint-subtext {
        color: #e2e8ce;
        font-size: 1.08em;
        font-weight: 500;
        margin: 0 0 18px 0;
        text-align: center;
        letter-spacing: 0.5px;
      }
      .goal-box {
        background: #2e3a2b;
        border-radius: 14px;
        padding: 20px 24px;
        margin: 0 24px 28px 24px;
        border: 1.5px solid #bfcf9b;
        font-family: 'Share Tech Mono', 'Fira Mono', 'Consolas', monospace;
        color: #e2e8ce;
        font-size: 1.18em;
        box-shadow: 0 2px 8px rgba(191,207,155,0.08);
      }
      .goal-label {
        font-weight: 700;
        color: #bfcf9b;
        font-size: 1.1em;
        margin-bottom: 6px;
        display: block;
      }
      .button-container {
        display: flex;
        gap: 12px;
        margin: 0 24px 28px 24px;
      }
      .button {
        flex: 1;
        padding: 16px;
        border: none;
        border-radius: 10px;
        font-size: 1.1em;
        font-weight: 700;
        cursor: pointer;
        transition: all 0.2s;
        font-family: inherit;
        position: relative;
        overflow: hidden;
        letter-spacing: 0.5px;
        box-shadow: 0 2px 8px rgba(0,0,0,0.08);
      }
      .button-back {
        background: linear-gradient(135deg, #e74c3c, #b71c1c);
        color: #fff;
        border: 2px solid #b71c1c;
      }
      .button-back:hover {
        background: linear-gradient(135deg, #b71c1c, #e74c3c);
      }
      .button-productive {
        background: linear-gradient(135deg, #4caf50, #2e7d32);
        color: #fff;
        border: 2px solid #2e7d32;
      }
      .button-productive:hover {
        background: linear-gradient(135deg, #2e7d32, #4caf50);
      }
      .feedback-form {
        display: none;
        margin: 0 24px 28px 24px;
      }
      .feedback-textarea {
        width: 100%;
        min-height: 100px;
        padding: 16px;
        border: 1.5px solid #bfcf9b;
        border-radius: 10px;
        font-family: inherit;
        font-size: 1.1em;
        background: #2e3a2b;
        color: #e2e8ce;
        resize: none;
        box-sizing: border-box;
        margin-bottom: 16px;
      }
      .feedback-textarea::placeholder {
        color: #bfcf9b;
        opacity: 0.7;
      }
      .button-submit {
        background: linear-gradient(135deg, #4caf50, #2e7d32);
        color: #fff;
        border: 2px solid #2e7d32;
        width: 100%;
      }
      .button-submit:hover {
        background: linear-gradient(135deg, #2e7d32, #4caf50);
      }
    </style>
    <div class="frosted-bg"></div>
    <div class="checkpoint-barrier">
      <!-- SVG: Checkpoint Barrier -->
      <svg width="420" height="60" viewBox="0 0 420 60" fill="none" xmlns="http://www.w3.org/2000/svg">
        <rect x="30" y="25" width="360" height="18" rx="7" fill="#bfcf9b" stroke="#6b7a4b" stroke-width="3"/>
        <rect x="40" y="29" width="40" height="10" rx="3" fill="#e74c3c"/>
        <rect x="90" y="29" width="40" height="10" rx="3" fill="#fff"/>
        <rect x="140" y="29" width="40" height="10" rx="3" fill="#e74c3c"/>
        <rect x="190" y="29" width="40" height="10" rx="3" fill="#fff"/>
        <rect x="240" y="29" width="40" height="10" rx="3" fill="#e74c3c"/>
        <rect x="290" y="29" width="40" height="10" rx="3" fill="#fff"/>
        <rect x="340" y="29" width="40" height="10" rx="3" fill="#e74c3c"/>
        <rect x="10" y="15" width="10" height="30" rx="3" fill="#6b7a4b"/>
        <rect x="400" y="15" width="10" height="30" rx="3" fill="#6b7a4b"/>
      </svg>
    </div>
    <div class="popup">
      <div class="popup-header">
        <span class="guard-svg">
          <svg width="80" height="80" viewBox="0 0 64 64" fill="none" xmlns="http://www.w3.org/2000/svg">
            <!-- Shield background -->
            <path d="M32 62C32 62 56 54 56 32V12L32 2L8 12V32C8 54 32 62 32 62Z" fill="#bfcf9b" stroke="#232b22" stroke-width="2"/>
            <!-- Image wrapper -->
            <clipPath id="shield-clip">
              <path d="M16 14L32 8L48 14V32C48 48 32 54 32 54C32 54 16 48 16 32V14Z"/>
            </clipPath>
            <!-- Your PNG image, now larger and more centered -->
            <image 
              href="${chrome.runtime.getURL('assets/soldier_head_transparent.png')}" 
              x="8" y="2" 
              width="48" height="60" 
              clip-path="url(#shield-clip)"
            />
            <!-- Shield border -->
            <path d="M32 62C32 62 56 54 56 32V12L32 2L8 12V32C8 54 32 62 32 62Z" fill="none" stroke="#232b22" stroke-width="2"/>
          </svg>
        </span>
        STOP
      </div>
      <div class="goal-box">
        <span class="goal-label">Current Goal:</span>
        <div>${sprintGoal ? sprintGoal : "No goal set"}</div>
      </div>
      <div class="button-container">
        <button id="deepwork-defender-go-back" class="button button-back">
          ← Go Back
        </button>
        <button id="deepwork-defender-feedback" class="button button-productive">
          This is actually productive
        </button>
      </div>
      <div id="deepwork-defender-feedback-form" class="feedback-form">
        <textarea 
          id="deepwork-defender-feedback-text" 
          class="feedback-textarea"
          placeholder="Why is this activity related to your goal?"
        ></textarea>
        <button id="deepwork-defender-submit-feedback" class="button button-submit">
          Submit Feedback
        </button>
      </div>
    </div>
  `;

  document.body.appendChild(overlay);

  // Event listeners
  const goBackBtn = shadow.getElementById('deepwork-defender-go-back');
  const feedbackBtn = shadow.getElementById('deepwork-defender-feedback');
  const feedbackForm = shadow.getElementById('deepwork-defender-feedback-form');
  const submitFeedbackBtn = shadow.getElementById('deepwork-defender-submit-feedback');

  if (goBackBtn) {
    goBackBtn.addEventListener('click', () => {
      chrome.runtime.sendMessage({ action: 'goBack' });
      overlay.remove();
    });
  }

  if (feedbackBtn) {
    feedbackBtn.addEventListener('click', () => {
      feedbackForm.style.display = 'block';
    });
  }

  if (submitFeedbackBtn) {
    submitFeedbackBtn.addEventListener('click', () => {
      const feedbackText = shadow.getElementById('deepwork-defender-feedback-text').value;
      chrome.runtime.sendMessage({
        type: 'SUBMIT_FEEDBACK',
        feedback: feedbackText,
        url: window.location.href
      });
      overlay.remove();
    });
  }
}

// Before any tracking/API call, check relaxMode
function shouldBlockForRelax() {
  if (!relaxMode) return false;
  
  // If there's an end time set
  if (relaxEndTime) {
    const now = Date.now();
    if (now > relaxEndTime) {
      // Relax time is over
      relaxMode = false;
      relaxEndTime = null;
      // Notify popup that relax mode ended
      chrome.runtime.sendMessage({ type: "RELAX_MODE_ENDED" });
      return false;
    }
    // Still in relax time
    return true;
  }
  
  return relaxMode;
}

// Add this helper function
function isBigSiteHomepage(url) {
  const urlObj = new URL(url);
  const domain = urlObj.hostname;
  const isHomepage = urlObj.pathname === '/' || urlObj.pathname === '';
  
  return BIG_SITES.some(site => domain.includes(site)) && isHomepage;
}

// Add this listener to handle navigation in the background script
chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
  if (message.action === 'goBack') {
    chrome.tabs.goBack(sender.tab.id, () => {
      if (chrome.runtime.lastError) {
        chrome.tabs.remove(sender.tab.id);
      }
    });
  }
});

// Modify startPhoneCheck function
async function startPhoneCheck() {
  console.log('startPhoneCheck called');
  
  const { userPhone } = await chrome.storage.local.get(['userPhone']);
  console.log('Retrieved userPhone:', userPhone);
  
  if (!userPhone) {
    console.warn('No phone number found in storage');
    return;
  }

  // Create an alarm for periodic checks
  chrome.alarms.create(PHONE_CHECK_ALARM, {
    delayInMinutes: 1, // Wait 1 minute before first check
    periodInMinutes: 1 // Then check every minute after that
  });

  console.log('Phone check scheduled to start in 60 seconds');
}

// New function to handle the actual check
async function doPhoneCheck() {
  try {
    const { phoneCheckStatus, focusSessionId, userPhone } = await chrome.storage.local.get(['phoneCheckStatus', 'focusSessionId', 'userPhone']);
    console.log('Current phone check status:', phoneCheckStatus);
    console.log('Current session ID:', focusSessionId);
    
    if (!focusSessionId || !userPhone) {
      console.error('Missing required data for phone check');
      return;
    }
    
    if (phoneCheckStatus?.checkAttempts >= MAX_PHONE_CHECK_ATTEMPTS) {
      console.log('Max attempts reached, stopping phone check');
      stopPhoneCheck();
      return;
    }

    // Format phone number properly
    const cleanPhone = userPhone.toString().replace(/\D/g, '');
    const formattedPhone = cleanPhone.length === 10 ? 
      `+1${cleanPhone}` : 
      cleanPhone.length === 11 && cleanPhone.startsWith('1') ? 
        `+${cleanPhone}` : 
        `+1${cleanPhone}`;

    console.log('Sending formatted phone:', formattedPhone);

    const result = await callApiWithAuth(`${API_BASE}/api/check-phone`, {
      phone: formattedPhone,
      sessionId: focusSessionId
    });

    console.log('API result:', result);

    // Handle backend unreachable case or rate limiting
    if (result.status === 'backend_unreachable' || result.status === 'rate_limited') {
      console.log('Backend unreachable or rate limited, will retry next interval');
      return;
    }

    // Use isPhoneOff directly from the API response
    const isPhoneOff = result.isPhoneOff;
    console.log('Is phone off?', isPhoneOff);

    const newStatus = {
      isPhoneOff,
      checkAttempts: (phoneCheckStatus?.checkAttempts || 0) + 1,
      lastCheckTime: Date.now()
    };

    await chrome.storage.local.set({ phoneCheckStatus: newStatus });

    // If phone is confirmed off, stop checking
    if (isPhoneOff) {
      console.log('Phone confirmed off, stopping checks');
      stopPhoneCheck();
      return;
    }

    // Only send warning if phone is still on
    if (!isPhoneOff) {
      try {
        chrome.runtime.sendMessage({ type: "PHONE_STILL_ON" });
      } catch (msgError) {
        console.log('Popup not open to receive warning');
      }
    }

  } catch (error) {
    console.error('Phone check error:', error);
  }
}

// Modify stopPhoneCheck
function stopPhoneCheck() {
  chrome.alarms.clear(PHONE_CHECK_ALARM);
  chrome.storage.local.set({
    phoneCheckStatus: {
      isPhoneOff: false,
      checkAttempts: 0,
      lastCheckTime: null
    }
  });
}

