import { callApiWithAuth } from '/scripts/utils/auth.js';
import { API_BASE } from '/scripts/config.js';

document.addEventListener('DOMContentLoaded', function() {
  // DOM elements
  const goalsList = document.getElementById('goal-items');
  const addGoalBtn = document.getElementById('add-goal-btn');
  const goalForm = document.getElementById('goal-form');
  const goalFormTitle = document.getElementById('goal-form-title');
  const sprintGoalInput = document.getElementById('sprint-goal');
  const saveGoalButton = document.getElementById('save-goal');
  const cancelGoalButton = document.getElementById('cancel-goal');
  const whitelistModal = document.getElementById('whitelist-modal');
  const whitelistList = document.getElementById('whitelist-list');
  const whitelistInput = document.getElementById('whitelist-input');
  const addWhitelistBtn = document.getElementById('add-whitelist-btn');
  const closeWhitelistBtn = document.getElementById('close-whitelist-btn');
  const relaxModeContainer = document.getElementById('relax-mode-container');
  const relaxModeStatus = document.getElementById('relax-mode-status');
  const relaxModeToggle = document.getElementById('relax-mode-toggle');
  const relaxTimerModal = document.getElementById('relax-timer-modal');
  const relaxMinutesInput = document.getElementById('relax-minutes-input');
  const relaxTimerStart = document.getElementById('relax-timer-start');
  const relaxTimerCancel = document.getElementById('relax-timer-cancel');
  const focusModeContainer = document.getElementById('focus-mode-container');
  const focusModeStatus = document.getElementById('focus-mode-status');
  const focusModeToggle = document.getElementById('focus-mode-toggle');
  const phoneInput = document.getElementById('phone-input');
  const phoneError = document.getElementById('phone-error');

  let editingGoalId = null;
  let currentWhitelistGoalId = null;
  let relaxMode = false;
  let relaxTimer = null;
  let relaxEndTime = null;
  let focusMode = false;

  // Email validation function
  function isValidEmail(email) {
    return /^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(email);
  }

  // Add these helper functions after isValidEmail
  function isValidPhoneNumber(phone) {
    // Strip all formatting to check raw digits
    const digits = phone.replace(/\D/g, '');
    // Must be exactly 10 digits or 11 digits starting with 1
    return /^1?\d{10}$/.test(digits);
  }

  function formatPhoneNumber(phone) {
    const digits = phone.replace(/\D/g, '');
    if (digits.length <= 3) {
      return digits;
    } else if (digits.length <= 6) {
      return `(${digits.slice(0,3)}) ${digits.slice(3)}`;
    } else {
      return `(${digits.slice(0,3)}) ${digits.slice(3,6)}-${digits.slice(6,10)}`;
    }
  }

  function unformatPhoneNumber(phone) {
    return phone.replace(/\D/g, '');
  }

  // Email modal elements
  const emailModal = document.getElementById('email-modal');
  const emailInput = document.getElementById('email-input');
  const saveEmailBtn = document.getElementById('save-contact-btn');
  const emailError = document.getElementById('email-error');
  const currentEmailSpan = document.getElementById('current-email');
  const changeEmailBtn = document.getElementById('change-email-btn');

  // Load goals on popup open
  loadGoals();

  // Event listeners
  addGoalBtn.addEventListener('click', () => showGoalForm());
  saveGoalButton.addEventListener('click', saveGoal);
  cancelGoalButton.addEventListener('click', hideGoalForm);

  function loadGoals() {
    chrome.storage.local.get(['goals', 'activeGoalId'], function(data) {
      const goals = data.goals || {};
      const activeGoalId = data.activeGoalId || null;
      renderGoals(goals, activeGoalId);
      hideGoalForm();
    });
  }

  function renderGoals(goals, activeGoalId) {
    goalsList.innerHTML = '';
    const goalIds = Object.keys(goals);
    if (goalIds.length === 0) {
      goalsList.innerHTML = '<p>No sprint goals yet. Add one!</p>';
      return;
    }
    goalIds.forEach(goalId => {
      const goal = goals[goalId];
      const div = document.createElement('div');
      div.className = 'goal-item';

      // Top row: radio + goal text
      const topRow = document.createElement('div');
      topRow.style.display = 'flex';
      topRow.style.alignItems = 'center';
      topRow.style.marginBottom = '10px';

      const radio = document.createElement('input');
      radio.type = 'radio';
      radio.name = 'active-goal';
      radio.value = goalId;
      radio.checked = goalId === activeGoalId;
      radio.addEventListener('change', () => setActiveGoal(goalId));
      radio.style.marginRight = '10px';

      const span = document.createElement('span');
      span.textContent = goal.text;
      span.style.flexGrow = '1';

      topRow.appendChild(radio);
      topRow.appendChild(span);

      // Bottom row: buttons
      const buttonRow = document.createElement('div');
      buttonRow.className = 'button-row';

      const editBtn = document.createElement('button');
      editBtn.className = 'edit-btn';
      editBtn.textContent = 'Edit';
      editBtn.addEventListener('click', () => {
        editingGoalId = goalId;
        renderGoals(goals, activeGoalId); // re-render to show edit form
      });

      const deleteBtn = document.createElement('button');
      deleteBtn.className = 'delete-btn';
      deleteBtn.textContent = 'Delete';
      deleteBtn.addEventListener('click', () => deleteGoal(goalId));

      buttonRow.appendChild(editBtn);
      buttonRow.appendChild(deleteBtn);

      div.appendChild(topRow);
      div.appendChild(buttonRow);

      goalsList.appendChild(div);

      // If this goal is being edited, show the edit form right below
      if (editingGoalId === goalId) {
        const editDiv = document.createElement('div');
        editDiv.className = 'edit-section';

        const textarea = document.createElement('textarea');
        textarea.value = goal.text;
        textarea.style.width = '100%';
        textarea.style.marginBottom = '10px';

        // Whitelisted Sites button
        const whitelistBtn = document.createElement('button');
        whitelistBtn.className = 'whitelist-btn';
        whitelistBtn.textContent = `Whitelisted Sites (${Object.keys(goal.whitelistedSites || {}).length})`;
        whitelistBtn.addEventListener('click', () => showWhitelistModal(goalId));

        // Save and Cancel buttons
        const saveBtn = document.createElement('button');
        saveBtn.className = 'edit-btn';
        saveBtn.textContent = 'Save';
        saveBtn.style.marginRight = '8px';
        saveBtn.addEventListener('click', () => {
          const newText = textarea.value.trim();
          if (!newText) {
            alert('Please enter a sprint goal');
            return;
          }
          goal.text = newText;
          goals[goalId] = goal;
          editingGoalId = null;
          chrome.storage.local.set({ goals }, () => renderGoals(goals, activeGoalId));
        });

        const cancelBtn = document.createElement('button');
        cancelBtn.className = 'delete-btn';
        cancelBtn.textContent = 'Cancel';
        cancelBtn.addEventListener('click', () => {
          editingGoalId = null;
          renderGoals(goals, activeGoalId);
        });

        // Button row for edit section
        const editButtonRow = document.createElement('div');
        editButtonRow.className = 'button-row';
        // editButtonRow.appendChild(whitelistBtn); // comment this out to remove the whitelist button, keep it for now
        editButtonRow.appendChild(saveBtn);
        editButtonRow.appendChild(cancelBtn);

        editDiv.appendChild(textarea);
        editDiv.appendChild(editButtonRow);

        goalsList.appendChild(editDiv);
      }
    });
  }

  function showGoalForm(goalId = null, text = '') {
    editingGoalId = goalId;
    goalFormTitle.textContent = goalId ? 'Edit Sprint Goal' : 'Add Sprint Goal';
    sprintGoalInput.value = text || '';
    goalForm.classList.remove('hidden');
  }

  function hideGoalForm() {
    editingGoalId = null;
    goalForm.classList.add('hidden');
    sprintGoalInput.value = '';
  }

  function saveGoal() {
    const text = sprintGoalInput.value.trim();
    if (!text) {
      alert('Please enter a sprint goal');
      return;
    }
    chrome.storage.local.get(['goals', 'activeGoalId'], function(data) {
      let goals = data.goals || {};
      let activeGoalId = data.activeGoalId || null;
      let goalId = editingGoalId || crypto.randomUUID();
      const isNew = !editingGoalId;
      goals[goalId] = goals[goalId] || {
        id: goalId,
        createdAt: Date.now(),
        whitelistedSites: {}
      };
      goals[goalId].text = text;
      if (isNew || !activeGoalId) activeGoalId = goalId;
      chrome.storage.local.set({ goals, activeGoalId }, loadGoals);
    });
  }

  function deleteGoal(goalId) {
    chrome.storage.local.get(['goals', 'activeGoalId'], function(data) {
      let goals = data.goals || {};
      let activeGoalId = data.activeGoalId || null;
      delete goals[goalId];
      // If deleted goal was active, pick another as active
      if (activeGoalId === goalId) {
        activeGoalId = Object.keys(goals)[0] || null;
      }
      chrome.storage.local.set({ goals, activeGoalId }, loadGoals);
    });
  }

  function setActiveGoal(goalId) {
    chrome.storage.local.set({ activeGoalId: goalId }, loadGoals);
  }

  // Whitelist modal logic
  function showWhitelistModal(goalId) {
    currentWhitelistGoalId = goalId;
    whitelistModal.classList.remove('hidden');
    whitelistInput.value = '';
    renderWhitelist();
  }

  function hideWhitelistModal() {
    whitelistModal.classList.add('hidden');
    currentWhitelistGoalId = null;
  }

  function renderWhitelist() {
    chrome.storage.local.get(['goals'], function(data) {
      const goals = data.goals || {};
      const goal = goals[currentWhitelistGoalId];
      const sites = goal && goal.whitelistedSites ? Object.keys(goal.whitelistedSites) : [];
      whitelistList.innerHTML = '';
      if (sites.length === 0) {
        whitelistList.innerHTML = '<li style="color: #888;">No sites whitelisted yet.</li>';
      } else {
        sites.forEach(domain => {
          const li = document.createElement('li');
          li.style.display = 'flex';
          li.style.justifyContent = 'space-between';
          li.style.alignItems = 'center';
          li.style.marginBottom = '6px';
          li.textContent = domain;
          const delBtn = document.createElement('button');
          delBtn.textContent = 'Remove';
          delBtn.style.fontSize = '11px';
          delBtn.style.background = '#e57373';
          delBtn.style.color = '#fff';
          delBtn.addEventListener('click', () => removeWhitelistedSite(domain));
          li.appendChild(delBtn);
          whitelistList.appendChild(li);
        });
      }
    });
  }

  function addWhitelistedSite() {
    const domain = whitelistInput.value.trim().toLowerCase();
    if (!domain) return;
    chrome.storage.local.get(['goals'], function(data) {
      const goals = data.goals || {};
      const goal = goals[currentWhitelistGoalId];
      if (!goal) return;
      goal.whitelistedSites = goal.whitelistedSites || {};
      goal.whitelistedSites[domain] = true;
      goals[currentWhitelistGoalId] = goal;
      chrome.storage.local.set({ goals }, () => {
        whitelistInput.value = '';
        renderWhitelist();
        loadGoals(); // update count in main list
      });
    });
  }

  function removeWhitelistedSite(domain) {
    chrome.storage.local.get(['goals'], function(data) {
      const goals = data.goals || {};
      const goal = goals[currentWhitelistGoalId];
      if (!goal) return;
      if (goal.whitelistedSites && goal.whitelistedSites[domain]) {
        delete goal.whitelistedSites[domain];
        goals[currentWhitelistGoalId] = goal;
        chrome.storage.local.set({ goals }, () => {
          renderWhitelist();
          loadGoals(); // update count in main list
        });
      }
    });
  }

  addWhitelistBtn.addEventListener('click', addWhitelistedSite);
  closeWhitelistBtn.addEventListener('click', hideWhitelistModal);

  // Helper to format time left
  function formatTimeLeft(ms) {
    const totalSeconds = Math.max(0, Math.floor(ms / 1000));
    const min = Math.floor(totalSeconds / 60);
    const sec = totalSeconds % 60;
    return `${min}:${sec.toString().padStart(2, '0')}`;
  }

  // Update Relax Mode UI
  function updateRelaxModeUI() {
    if (relaxMode) {
      relaxModeContainer.classList.add('relax-active');
      let timeLeft = relaxEndTime ? formatTimeLeft(relaxEndTime - Date.now()) : '';
      relaxModeStatus.textContent = `Relax Mode is ON${timeLeft ? ` (${timeLeft} left)` : ''}`;
      relaxModeToggle.textContent = "End Relax";
      relaxModeToggle.style.background = "#e65100";
      relaxModeToggle.style.color = "#fff";
    } else {
      relaxModeContainer.classList.remove('relax-active');
      relaxModeStatus.textContent = "Relax Mode is OFF";
      relaxModeToggle.textContent = "Start Relax";
      relaxModeToggle.style.background = "#388e3c";
      relaxModeToggle.style.color = "#fff";
    }
  }

  // Start Relax Mode
  function startRelaxMode(minutes) {
    relaxMode = true;
    relaxEndTime = minutes === null ? null : Date.now() + minutes * 60 * 1000;
    chrome.storage.local.set({ relaxMode, relaxEndTime });
    updateRelaxModeUI();
    if (relaxEndTime !== null) {
      startRelaxCountdown();
    }
    // Notify background
    chrome.runtime.sendMessage({ type: "RELAX_MODE_ON", until: relaxEndTime });
  }

  // End Relax Mode
  function endRelaxMode() {
    relaxMode = false;
    relaxEndTime = null;
    chrome.storage.local.set({ relaxMode, relaxEndTime: null });
    updateRelaxModeUI();
    if (relaxTimer) clearTimeout(relaxTimer);
    // Notify background
    chrome.runtime.sendMessage({ type: "RELAX_MODE_OFF" });
  }

  // Countdown logic
  function startRelaxCountdown() {
    if (relaxTimer) clearTimeout(relaxTimer);
    if (!relaxMode || !relaxEndTime) return;
    const msLeft = relaxEndTime - Date.now();
    if (msLeft <= 0) {
      endRelaxMode();
      return;
    }
    updateRelaxModeUI();
    relaxTimer = setTimeout(startRelaxCountdown, 1000);
  }

  // Toggle handler
  relaxModeToggle.addEventListener('click', function() {
    if (relaxMode) {
      endRelaxMode();
    } else {
      showRelaxModeDialog();
    }
  });

  // On load, restore relax mode state
  chrome.storage.local.get(['relaxMode', 'relaxEndTime'], (data) => {
    relaxMode = !!data.relaxMode;
    relaxEndTime = data.relaxEndTime;
    if (relaxMode && (relaxEndTime === null || relaxEndTime > Date.now())) {
      if (relaxEndTime !== null) startRelaxCountdown();
      // else: indefinite relax mode, no countdown needed
    } else {
      relaxMode = false;
      relaxEndTime = null;
      chrome.storage.local.set({ relaxMode: false, relaxEndTime: null });
    }
    updateRelaxModeUI();
  });

  function showRelaxTimerModal(onStart) {
    relaxTimerModal.classList.remove('hidden');
    relaxMinutesInput.value = 15;
    relaxMinutesInput.focus();

    function cleanup() {
      relaxTimerModal.classList.add('hidden');
      relaxTimerStart.removeEventListener('click', onStartClick);
      relaxTimerCancel.removeEventListener('click', onCancelClick);
    }

    function onStartClick() {
      let mins = parseInt(relaxMinutesInput.value, 10);
      if (isNaN(mins) || mins <= 0) mins = 15;
      cleanup();
      onStart(mins);
    }

    function onCancelClick() {
      cleanup();
    }

    relaxTimerStart.addEventListener('click', onStartClick);
    relaxTimerCancel.addEventListener('click', onCancelClick);
  }

  const relaxBtn = document.getElementById('start-relax-mode');
  if (relaxBtn) {
    relaxBtn.onclick = () => {
      chrome.runtime.sendMessage({ type: "RELAX_MODE_ON", until: Date.now() + 15 * 60 * 1000 });
      // Optionally, close the warning overlay
    };
  }

  function createWarningPopup(memeURL, sprintGoal) {
    if (document.getElementById('sprint-copilot-warning-overlay')) {
      return;
    }

    // Create overlay
    const overlay = document.createElement('div');
    overlay.id = 'sprint-copilot-warning-overlay';
    overlay.style = `
      position: fixed;
      top: 0; left: 0; right: 0; bottom: 0;
      background: rgba(44, 62, 80, 0.18);
      z-index: 999999;
      display: flex;
      align-items: center;
      justify-content: center;
    `;

    // Create popup
    const popup = document.createElement('div');
    popup.id = 'sprint-copilot-warning';
    popup.style = `
      background: #fff;
      border-radius: 32px;
      box-shadow: 0 8px 32px rgba(0,0,0,0.18);
      padding: 0 0 40px 0;
      max-width: 80vw;
      max-height: 80vh;
      width: 80vw;
      height: 80vh;
      display: flex;
      flex-direction: column;
      align-items: center;
      justify-content: center;
      overflow: auto;
    `;
    
    popup.innerHTML = `
      <div style="width: 100%; max-width: 600px; margin: 0 auto;">
        <div style="background: #ff9800; color: #fff; border-radius: 20px; padding: 28px 0 28px 32px; font-size: 2.2em; font-weight: 700; display: flex; align-items: center; gap: 18px; margin-bottom: 36px;">
          <span style="font-size: 1.3em;">&#9888;</span>
          <span>STOP</span>
        </div>
        <div style="background: #f4f4f4; border-radius: 18px; padding: 24px 32px; margin-bottom: 36px;">
          <span style="font-weight: 600; color: #444; font-size: 1.3em;">Current Goal:</span>
          <div style="font-size: 1.5em; margin-top: 12px; color: #222;">${sprintGoal ? sprintGoal : "No goal set"}</div>
        </div>
        <button id="sprint-copilot-feedback" style="
          display: block;
          width: 100%;
          padding: 20px;
          background: linear-gradient(135deg, #4285f4, #3b78e7);
          color: white;
          border: none;
          border-radius: 10px;
          font-size: 1.2em;
          font-weight: 600;
          cursor: pointer;
          transition: all 0.2s;
          font-family: inherit;
          box-sizing: border-box;
          margin-top: 0;
          margin-bottom: 0;
        ">This is actually productive</button>
        <div id="sprint-copilot-feedback-form" style="display: none; margin-top: 24px; font-family: inherit;">
          <textarea id="sprint-copilot-feedback-text" 
            placeholder="Why is this activity related to your goal?" 
            style="
              width: 100%;
              min-height: 120px;
              padding: 16px;
              margin-bottom: 18px;
              border: 1px solid #ddd;
              border-radius: 10px;
              font-family: inherit;
              font-size: 1.1em;
              resize: none;
              box-sizing: border-box;
            "
          ></textarea>
          <button id="sprint-copilot-submit-feedback" style="
            display: block;
            width: 100%;
            padding: 18px;
            background: linear-gradient(135deg, #40c057, #37b24d);
            color: white;
            border: none;
            border-radius: 10px;
            font-size: 1.1em;
            font-weight: 600;
            cursor: pointer;
            transition: all 0.2s;
            font-family: inherit;
            box-sizing: border-box;
          ">Submit Feedback</button>
        </div>
      </div>
    `;

    overlay.appendChild(popup);
    document.body.appendChild(overlay);

    // ...existing event listeners and logic...
  }

  function showRelaxModeDialog() {
    const dialog = document.createElement('div');
    dialog.id = 'relax-mode-dialog';
    dialog.style.cssText = `
      position: fixed;
      top: 50%;
      left: 50%;
      transform: translate(-50%, -50%);
      background: #fffbe7;
      padding: 0;
      border-radius: 14px;
      box-shadow: 0 2px 10px rgba(0,0,0,0.13);
      z-index: 1000;
      min-width: 320px;
      font-family: inherit;
    `;

    dialog.innerHTML = `
      <div style="background: #ffb300; color: #fff; border-radius: 14px 14px 0 0; padding: 18px 24px; font-size: 1.25em; font-weight: 700; display: flex; align-items: center; gap: 12px;">
        <span style="font-size: 1.3em;">&#9888;</span>
        <span>Start Relax Mode</span>
      </div>
      <div style="padding: 22px 24px 18px 24px;">
        <div style="margin-bottom: 18px;">
          <label style="display: flex; align-items: center; gap: 10px; cursor: pointer; font-size: 1.05em;">
            <input type="checkbox" id="indefinite-relax" style="width: 16px; height: 16px;">
            <span>Until I turn off</span>
          </label>
        </div>
        <div id="minutes-input" style="margin-bottom: 18px; min-height: 56px; display: flex; flex-direction: column; justify-content: center;">
          <label style="margin-bottom: 6px; color: #d18f00;">How many minutes to relax?</label>
          <input type="number" id="relax-minutes" value="15" min="1" style="
            width: calc(100% - 32px);
            padding: 10px 16px;
            border: 1px solid #ffe082;
            border-radius: 7px;
            font-size: 1.1em;
            background: #fffde7;
            color: #222;
          ">
        </div>
        <div style="display: flex; gap: 12px;">
          <button id="cancel-relax" style="
            flex: 1;
            padding: 14px 0;
            border: none;
            border-radius: 8px;
            background: #ffeaea;
            color: #d32f2f;
            font-size: 1.1em;
            font-weight: 600;
            cursor: pointer;
            transition: all 0.18s;
          ">Cancel</button>
          <button id="start-relax" style="
            flex: 1;
            padding: 14px 0;
            border: none;
            border-radius: 8px;
            background: #43a047;
            color: #fff;
            font-size: 1.1em;
            font-weight: 600;
            cursor: pointer;
            transition: all 0.18s;
          ">Start</button>
        </div>
      </div>
    `;

    document.body.appendChild(dialog);

    // Add event listeners after the element exists
    document.getElementById('indefinite-relax').addEventListener('change', function() {
      const minutesInput = document.getElementById('minutes-input');
      // Hide input but keep space reserved
      if (this.checked) {
        minutesInput.style.visibility = 'hidden';
      } else {
        minutesInput.style.visibility = 'visible';
      }
    });

    document.getElementById('start-relax').addEventListener('click', function() {
      const isIndefinite = document.getElementById('indefinite-relax').checked;
      const minutes = parseInt(document.getElementById('relax-minutes').value) || 15;
      if (isIndefinite) {
        startRelaxMode(null); // Pass null for indefinite mode
      } else {
        startRelaxMode(minutes);
      }
      dialog.remove();
    });

    document.getElementById('cancel-relax').addEventListener('click', function() {
      dialog.remove();
    });
  }

  // Show email modal
  function showEmailModal() {
    emailModal.style.display = 'block';
    document.querySelector('.container').style.filter = 'blur(3px)';
  }

  // Hide email modal
  function hideEmailModal() {
    emailModal.style.display = 'none';
    document.querySelector('.container').style.filter = 'none';
  }

  // Save email
  async function saveEmail(email) {
    await chrome.storage.local.set({ userEmail: email });
    currentEmailSpan.textContent = `Email: ${email}`;
    hideEmailModal();
  }

  // Check for email on load
  chrome.storage.local.get('userEmail', ({ userEmail }) => {
    if (!userEmail) {
      showEmailModal();
    } else {
      currentEmailSpan.textContent = `Email: ${userEmail}`;
      hideEmailModal();
    }
  });

  // Email input handlers
  saveEmailBtn.addEventListener('click', () => {
    const email = emailInput.value.trim();
    if (isValidEmail(email)) {
      emailError.style.display = 'none';
      saveEmail(email);
    } else {
      emailError.style.display = 'block';
    }
  });

  changeEmailBtn.addEventListener('click', () => {
    showEmailModal();
  });

  // Update Focus Mode UI
  function updateFocusModeUI() {
    focusModeStatus.textContent = `Focus Mode is ${focusMode ? 'ON' : 'OFF'}`;
    focusModeToggle.textContent = focusMode ? 'Turn Off' : 'Turn On';
    focusModeToggle.style.background = focusMode ? '#6200ea' : '#9e9e9e';
    focusModeToggle.style.color = focusMode ? '#ffffff' : '#ffffff';
    document.body.style.background = focusMode ? '#f3e5f5' : '#ffffff';
    relaxModeContainer.style.display = focusMode ? 'flex' : 'none';
  }

  // Add focus mode toggle handler
  focusModeToggle.addEventListener('click', () => {
    focusMode = !focusMode;
    chrome.storage.local.set({ focusMode });
    updateFocusModeUI();
    
    if (focusMode) {
      showFocusModeDialog();
      // Start phone checking
      chrome.runtime.sendMessage({ type: "FOCUS_MODE_ON" });
    } else {
      // Stop phone checking
      chrome.runtime.sendMessage({ type: "FOCUS_MODE_OFF" });
    }
  });

  // On DOMContentLoaded, restore focus mode state from storage
  chrome.storage.local.get(['focusMode'], (data) => {
    focusMode = !!data.focusMode; // restore persisted value, default to false if not set
    updateFocusModeUI();
  });

  // Add phone input handler
  phoneInput.addEventListener('input', (e) => {
    const formatted = formatPhoneNumber(e.target.value);
    e.target.value = formatted;
  });

  // Update save handler
  saveEmailBtn.addEventListener('click', () => {
    const email = emailInput.value.trim();
    const phone = phoneInput.value.trim();
    const rawPhone = unformatPhoneNumber(phone);
    
    let isValid = true;
    
    if (!isValidEmail(email)) {
      emailError.style.display = 'block';
      isValid = false;
    } else {
      emailError.style.display = 'none';
    }
    
    if (!isValidPhoneNumber(rawPhone)) {
      phoneError.style.display = 'block';
      isValid = false;
    } else {
      phoneError.style.display = 'none';
    }
    
    if (isValid) {
      saveContact(email, rawPhone);
    }
  });

  // Update save function
  async function saveContact(email, phone) {
    try {
      await chrome.storage.local.set({ 
        userEmail: email,
        userPhone: phone 
      });
      hideEmailModal();
    } catch (error) {
      console.error('Error saving contact:', error);
    }
  }

  function showFocusModeDialog() {
    const dialog = document.createElement('div');
    dialog.id = 'focus-mode-dialog';
    dialog.style.cssText = `
      position: fixed;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      background: rgba(0, 0, 0, 0.5);
      display: flex;
      justify-content: center;
      align-items: center;
      z-index: 1000;
    `;

    dialog.innerHTML = `
      <div style="
        background: #f3e5f5;
        padding: 0;
        border-radius: 14px;
        box-shadow: 0 2px 10px rgba(0,0,0,0.13);
        min-width: 320px;
        font-family: inherit;
      ">
        <div style="background: #6200ea; color: #fff; border-radius: 14px 14px 0 0; padding: 18px 24px; font-size: 1.25em; font-weight: 700; display: flex; align-items: center; gap: 12px;">
          <img src="../assets/soldier_logo.jpg" alt="Soldier Logo" style="height: 32px; width: 32px; border-radius: 50%;">
          <span>Let's lock in! 🎯</span>
        </div>
        <div style="padding: 22px 24px 18px 24px;">
          <p style="margin: 0 0 24px 0; font-size: 1.2em; text-align: center;">Remember to "Turn Off Your Phone"</p>
          <button id="acknowledge-focus" style="
            width: 100%;
            padding: 14px 0;
            border: none;
            border-radius: 8px;
            background: #6200ea;
            color: #fff;
            font-size: 1.1em;
            font-weight: 600;
            cursor: pointer;
            transition: all 0.18s;
          ">Got it!</button>
        </div>
      </div>
    `;

    document.body.appendChild(dialog);
    document.querySelector('.container').style.filter = 'blur(3px)';

    document.getElementById('acknowledge-focus').addEventListener('click', function() {
      dialog.remove();
      document.querySelector('.container').style.filter = 'none';
    });
  }

  function showPhoneWarningDialog() {
    const dialog = document.createElement('div');
    dialog.id = 'phone-warning-dialog';
    dialog.style.cssText = `
      position: fixed;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      background: rgba(0, 0, 0, 0.5);
      display: flex;
      justify-content: center;
      align-items: center;
      z-index: 1000;
    `;

    dialog.innerHTML = `
      <div style="
        background: #fff3e0;
        padding: 0;
        border-radius: 14px;
        box-shadow: 0 2px 10px rgba(0,0,0,0.13);
        min-width: 320px;
        font-family: inherit;
      ">
        <div style="background: #ff6d00; color: #fff; border-radius: 14px 14px 0 0; padding: 18px 24px; font-size: 1.25em; font-weight: 700; display: flex; align-items: center; gap: 12px;">
          <span style="font-size: 1.3em;">⚠️</span>
          <span>Phone Still Active!</span>
        </div>
        <div style="padding: 22px 24px 18px 24px;">
          <p style="margin: 0 0 24px 0; font-size: 1.2em; text-align: center;">Please turn off your phone to maintain focus.</p>
          <button id="acknowledge-warning" style="
            width: 100%;
            padding: 14px 0;
            border: none;
            border-radius: 8px;
            background: #ff6d00;
            color: #fff;
            font-size: 1.1em;
            font-weight: 600;
            cursor: pointer;
            transition: all 0.18s;
          ">Got it!</button>
        </div>
      </div>
    `;

    document.body.appendChild(dialog);
    document.querySelector('.container').style.filter = 'blur(3px)';

    document.getElementById('acknowledge-warning').addEventListener('click', function() {
      dialog.remove();
      document.querySelector('.container').style.filter = 'none';
    });
  }

  // Listen for phone warning messages from background
  chrome.runtime.onMessage.addListener((message) => {
    if (message.type === "PHONE_STILL_ON") {
      showPhoneWarningDialog();
    }
  });
});