// Add at the top with other imports
import { API_BASE } from '/scripts/config.js';
const SUPABASE_URL = 'https://ktxglgynarudevzpikkd.supabase.co';
const SUPABASE_ANON_KEY = 'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJpc3MiOiJzdXBhYmFzZSIsInJlZiI6Imt0eGdsZ3luYXJ1ZGV2enBpa2tkIiwicm9sZSI6ImFub24iLCJpYXQiOjE3NDc5NjY2NjMsImV4cCI6MjA2MzU0MjY2M30.HZuUe12QPccal007CUImkQshX_JofSdzctD2LKElLvg';

// Utility for UUID v4 generation
function generateUUIDv4() {
  // https://stackoverflow.com/a/2117523/508355
  return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function(c) {
    var r = Math.random() * 16 | 0, v = c === 'x' ? r : (r & 0x3 | 0x8);
    return v.toString(16);
  });
}

// Get or create extensionId
export async function getExtensionId() {
  return new Promise((resolve) => {
    chrome.storage.local.get(['extensionId'], (data) => {
      if (data.extensionId) {
        resolve(data.extensionId);
      } else {
        const newId = generateUUIDv4();
        chrome.storage.local.set({ extensionId: newId }, () => resolve(newId));
      }
    });
  });
}

// Get or set backend URL (configurable)
export async function getBackendUrl() {
  return new Promise((resolve) => {
    chrome.storage.local.get(['backendUrl'], (data) => {
      if (data.backendUrl) {
        resolve(data.backendUrl);
      } else {
        chrome.storage.local.set({ backendUrl: API_BASE }, () => resolve(API_BASE));
      }
    });
  });
}

// Register and get JWT token
export async function registerAndGetToken() {
  const extensionId = await getExtensionId();
  const backendUrl = await getBackendUrl();
  const registerUrl = `${backendUrl}/api/register`;
  
  try {
    const res = await fetch(registerUrl, {
      method: 'POST',
      headers: { 'Content-Type': 'application/json' },
      body: JSON.stringify({ extensionId })
    });
    
    if (!res.ok) throw new Error('Registration failed');
    const data = await res.json();
    
    if (data.token) {
      await new Promise((resolve) => 
        chrome.storage.local.set({ jwtToken: data.token }, resolve)
      );
      return data.token;
    }
    throw new Error('No token in response');
  } catch (err) {
    console.error('Error registering extension:', err);
    throw err;
  }
}

// Get a valid JWT token, re-register if missing/expired
export async function ensureValidToken() {
  return new Promise((resolve, reject) => {
    chrome.storage.local.get(['jwtToken'], async (data) => {
      let token = data.jwtToken;
      if (!token) {
        try {
          token = await registerAndGetToken();
          resolve(token);
        } catch (err) {
          reject(err);
        }
      } else {
        resolve(token);
      }
    });
  });
}

// Make an authenticated API call, handle 401/403 by re-registering
export async function callApiWithAuth(endpoint, payload) {
  const backendUrl = await getBackendUrl();
  let token = await ensureValidToken();
  let url = endpoint.startsWith('http') ? endpoint : `${backendUrl}${endpoint}`;
  let res;
  let success = false;
  let error_message = null;
  
  try {
    res = await fetch(url, {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
        'Authorization': `Bearer ${token}`
      },
      body: JSON.stringify(payload)
    });

    // Handle rate limiting for phone checks
    if (res.status === 429 && endpoint.includes('/check-phone')) {
      console.log('Rate limited, will retry in 60 seconds');
      // Return a fake success response to prevent error
      return {
        callDuration: 0,
        status: 'rate_limited'
      };
    }

    if (res.status === 401 || res.status === 403) {
      await new Promise((resolve) => chrome.storage.local.remove('jwtToken', resolve));
      token = await registerAndGetToken();
      res = await fetch(url, {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
          'Authorization': `Bearer ${token}`
        },
        body: JSON.stringify(payload)
      });
    }

    const responseData = await res.json();
    success = res.ok;
    if (!res.ok) error_message = `HTTP error! status: ${res.status}`;

    // Log the event
    const extensionId = await getExtensionId();
    await logExtensionEvent({
      event_type: endpoint.includes('/classify') ? 'classify' : 
                 endpoint.includes('/feedback') ? 'feedback' : 
                 endpoint.includes('/register') ? 'register' : 'unknown',
      extension_id: extensionId,
      url: payload.url,
      goal: payload.sprintGoal || payload.goal,
      feedback: payload.feedback,
      classification_result: endpoint.includes('/classify') ? responseData : null,
      website_description: responseData.websiteDescription,
      token_count: responseData.tokenCount,
      success,
      error_message
    });

    if (!res.ok) throw new Error(error_message);
    return responseData;

  } catch (err) {
    error_message = err.message;
    success = false;
    
    // Log error event
    const extensionId = await getExtensionId();
    await logExtensionEvent({
      event_type: endpoint.includes('/classify') ? 'classify' : 
                 endpoint.includes('/feedback') ? 'feedback' : 
                 endpoint.includes('/register') ? 'register' : 'unknown',
      extension_id: extensionId,
      url: payload.url,
      goal: payload.sprintGoal || payload.goal,
      feedback: payload.feedback,
      success: false,
      error_message: err.message
    });

    if (err instanceof TypeError || err.message.includes('Failed to fetch')) {
      return { aligned: true, explanation: 'Offline mode: backend unreachable.' };
    }
    throw err;
  }
}

// Add this function
async function logExtensionEvent(eventData) {
  const { userEmail, userPhone } = await chrome.storage.local.get(['userEmail', 'userPhone']);
  
  try {
    const response = await fetch(`${SUPABASE_URL}/rest/v1/extension_events`, {
      method: 'POST',
      headers: {
        'apikey': SUPABASE_ANON_KEY,
        'Content-Type': 'application/json',
        'Prefer': 'return=minimal'
      },
      body: JSON.stringify({
        ...eventData,
        email: userEmail || 'unknown',
        phone: userPhone || 'unknown'
      })
    });
    if (!response.ok) throw new Error(`HTTP error! status: ${response.status}`);
  } catch (error) {
    console.error('Failed to log event:', error);
  }
} 